==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/WebDisplayDensityBaseDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Description } from "./Description";
import { markType } from "./type";
/**
 * @hidden
 */
var WebDisplayDensityBaseDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebDisplayDensityBaseDescription, _super);
    function WebDisplayDensityBaseDescription() {
        var _this = _super.call(this) || this;
        _this.f = null;
        _this.g = null;
        return _this;
    }
    WebDisplayDensityBaseDescription.prototype.get_type = function () {
        return "WebDisplayDensityBase";
    };
    Object.defineProperty(WebDisplayDensityBaseDescription.prototype, "type", {
        get: function () {
            return this.get_type();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebDisplayDensityBaseDescription.prototype, "displayDensity", {
        get: function () {
            return this.f;
        },
        set: function (a) {
            this.f = a;
            this.e("DisplayDensity");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebDisplayDensityBaseDescription.prototype, "onDensityChangedRef", {
        get: function () {
            return this.g;
        },
        set: function (a) {
            this.g = a;
            this.e("OnDensityChangedRef");
        },
        enumerable: true,
        configurable: true
    });
    WebDisplayDensityBaseDescription.$t = markType(WebDisplayDensityBaseDescription, 'WebDisplayDensityBaseDescription', Description.$);
    return WebDisplayDensityBaseDescription;
}(Description));
export { WebDisplayDensityBaseDescription };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/WebDisplayDensityBaseDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Description } from "./Description";
import { markType } from "./type";
/**
 * @hidden
 */
var WebDisplayDensityBaseDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebDisplayDensityBaseDescription, _super);
    function WebDisplayDensityBaseDescription() {
        var _this = _super.call(this) || this;
        _this.g = null;
        _this.f = null;
        return _this;
    }
    WebDisplayDensityBaseDescription.prototype.get_type = function () {
        return "WebDisplayDensityBase";
    };
    Object.defineProperty(WebDisplayDensityBaseDescription.prototype, "type", {
        get: function () {
            return this.get_type();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebDisplayDensityBaseDescription.prototype, "displayDensity", {
        get: function () {
            return this.g;
        },
        set: function (a) {
            this.g = a;
            this.e("DisplayDensity");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebDisplayDensityBaseDescription.prototype, "densityChangedRef", {
        get: function () {
            return this.f;
        },
        set: function (a) {
            this.f = a;
            this.e("DensityChangedRef");
        },
        enumerable: true,
        configurable: true
    });
    WebDisplayDensityBaseDescription.$t = markType(WebDisplayDensityBaseDescription, 'WebDisplayDensityBaseDescription', Description.$);
    return WebDisplayDensityBaseDescription;
}(Description));
export { WebDisplayDensityBaseDescription };
